"""Reflex custom component Simple Icons."""

# For wrapping react guide, visit https://reflex.dev/docs/wrapping-react/overview/

import reflex as rx


class Simpleicons(rx.Component):
    """
    This is the Simpleicons class. When constructing a Simpleicons object, you can specify the following fields:

    - tag: A tag for the icon.
    - size: The size of the icon.
    - color: The color of the icon.

    Example usage:
    simpleicons_obj = Simpleicons(tag='TheTag', size='TheSize', color='TheColor')
    """

    # The React library to wrap.
    library = "@icons-pack/react-simple-icons"

    # The React component tag.
    tag = "None"

    # Default Size.
    size = 48

    @classmethod
    def create(cls, *children, **props) -> rx.Component:
        """Initialize the Icon component.

               Run some additional checks on Simple Icons component.

               Args:
                   *children: The positional arguments
                   **props: The keyword arguments

               Raises:
                   AttributeError: The errors tied to bad usage of the Icon component.
                   ValueError: If the Simple icon tag is invalid.

               Returns:
                   The created component.
               """
        if children:
            if len(children) == 1 and type(children[0]) == str:
                props["tag"] = children[0]
            else:
                raise AttributeError(
                    f"Passing multiple children to Simpleicons component is not allowed: remove positional "
                    f"argument: {children[1:]} to fix"
                )
        if "tag" not in props.keys():
            raise AttributeError("Missing 'tag' keyword-argument for Simpleicons")

        if (
            type(props["tag"]) != str
            or props["tag"].lower() not in SIMPLE_ICONS_LIST
        ):
            raise ValueError(f"Invalid icon tag: {props['tag']}. See full list at "
                             f"https://simpleicons.org/"
                             )

        props["tag"] = f"Si{props['tag'].capitalize()}"

        return super().create(*children, **props)


simpleicons = Simpleicons.create

SIMPLE_ICONS_LIST = ['1001tracklists', '1password', '2k', '365datascience', '3m', '42', '4chan', '4d', '500px', '7zip',
                     '99designs', '9gag', 'abbott', 'abbrobotstudio', 'abbvie', 'aboutdotme', 'abstract', 'academia',
                     'accenture', 'accusoft', 'acer', 'acm', 'actigraph', 'activision', 'activitypub', 'actix', 'acura',
                     'adafruit', 'adblock', 'adblockplus', 'adguard', 'adidas', 'adminer', 'adobe',
                     'adobeacrobatreader', 'adobeaftereffects', 'adobeaudition', 'adobecreativecloud',
                     'adobedreamweaver', 'adobefonts', 'adobeillustrator', 'adobeindesign', 'adobelightroom',
                     'adobelightroomclassic', 'adobephotoshop', 'adobepremierepro', 'adobexd', 'adonisjs', 'adp',
                     'adroll', 'adventofcode', 'adyen', 'aerlingus', 'aeroflot', 'aeromexico', 'aerospike', 'aew',
                     'affine', 'affinity', 'affinitydesigner', 'affinityphoto', 'affinitypublisher', 'aframe',
                     'afterpay', 'agora', 'aib', 'aidungeon', 'aiohttp', 'aiqfome', 'airasia', 'airbnb',
                     'airbrakedotio', 'airbus', 'airbyte', 'aircall', 'aircanada', 'airchina', 'airfrance', 'airindia',
                     'airplayaudio', 'airplayvideo', 'airtable', 'airtel', 'airtransat', 'ajv', 'akamai', 'akaunting',
                     'akiflow', 'alacritty', 'alamy', 'albertheijn', 'alby', 'alchemy', 'aldinord', 'aldisud',
                     'alfaromeo', 'alfred', 'algolia', 'algorand', 'alibabacloud', 'alibabadotcom', 'alienware',
                     'aliexpress', 'alipay', 'allegro', 'alliedmodders', 'allocine', 'alltrails', 'almalinux',
                     'alpinedotjs', 'alpinelinux', 'alteryx', 'altiumdesigner', 'alwaysdata', 'alx', 'amazon',
                     'amazonalexa', 'amazonapigateway', 'amazonaws', 'amazoncloudwatch', 'amazondocumentdb',
                     'amazondynamodb', 'amazonec2', 'amazonecs', 'amazoneks', 'amazonfiretv', 'amazongames',
                     'amazoniam', 'amazonlumberyard', 'amazonluna', 'amazonmusic', 'amazonpay', 'amazonprime',
                     'amazonrds', 'amazonredshift', 'amazonroute53', 'amazons3', 'amazonsimpleemailservice',
                     'amazonsqs', 'amd', 'ameba', 'americanairlines', 'americanexpress', 'amg', 'amp', 'amul', 'ana',
                     'anaconda', 'analogue', 'andela', 'android', 'androidauto', 'androidstudio', 'angular', 'anilist',
                     'animalplanet', 'ankermake', 'ansible', 'answer', 'ansys', 'anta', 'antdesign', 'antena3',
                     'anydesk', 'aol', 'apache', 'apacheairflow', 'apacheant', 'apachecassandra', 'apachecloudstack',
                     'apachecordova', 'apachecouchdb', 'apachedruid', 'apacheecharts', 'apacheflink',
                     'apachefreemarker', 'apachegroovy', 'apacheguacamole', 'apachehadoop', 'apachehive',
                     'apachejmeter', 'apachekafka', 'apachekylin', 'apachemaven', 'apachenetbeanside',
                     'apacheopenoffice', 'apacheparquet', 'apachepulsar', 'apacherocketmq', 'apachesolr', 'apachespark',
                     'apachestorm', 'apachetomcat', 'aparat', 'apifox', 'apmterminals', 'apollographql', 'apostrophe',
                     'appian', 'appium', 'apple', 'applearcade', 'applemusic', 'applenews', 'applepay', 'applepodcasts',
                     'appletv', 'appsignal', 'appsmith', 'appstore', 'appveyor', 'appwrite', 'aqua', 'aral', 'arangodb',
                     'arc', 'arcgis', 'archicad', 'archiveofourown', 'archlinux', 'ardour', 'arduino', 'argo', 'argos',
                     'ariakit', 'arkecosystem', 'arlo', 'arm', 'armkeil', 'arstechnica', 'artifacthub', 'artixlinux',
                     'artstation', 'arxiv', 'asahilinux', 'asana', 'asciidoctor', 'asciinema', 'asda', 'aseprite',
                     'askfm', 'assemblyscript', 'astonmartin', 'astro', 'asus', 'atandt', 'atari', 'atlassian',
                     'auchan', 'audacity', 'audi', 'audible', 'audioboom', 'audiomack', 'audiotechnica', 'aurelia',
                     'auth0', 'authelia', 'authy', 'autocad', 'autodesk', 'autodeskmaya', 'autodeskrevit', 'autohotkey',
                     'autoit', 'automattic', 'autoprefixer', 'autozone', 'avajs', 'avast', 'avianca', 'avira',
                     'awesomelists', 'awesomewm', 'awsamplify', 'awsfargate', 'awslambda', 'awsorganizations', 'axios',
                     'azureartifacts', 'azuredataexplorer', 'azuredevops', 'azurefunctions', 'azurepipelines', 'babel',
                     'babelio', 'backblaze', 'backbonedotjs', 'backendless', 'backstage', 'badoo', 'baidu', 'bakalari',
                     'bamboo', 'bandcamp', 'bandlab', 'bandrautomation', 'bandsintown', 'bankofamerica', 'barclays',
                     'baremetrics', 'barmenia', 'basecamp', 'basicattentiontoken', 'bastyon', 'bata', 'battledotnet',
                     'bazel', 'beatport', 'beats', 'beatsbydre', 'behance', 'beijingsubway', 'bem', 'bentley', 'bento',
                     'bentobox', 'bentoml', 'bereal', 'betfair', 'betterstack', 'bevy', 'bigbasket', 'bigbluebutton',
                     'bigcartel', 'bigcommerce', 'bilibili', 'billboard', 'bim', 'binance', 'biolink', 'biome',
                     'bisecthosting', 'bit', 'bitbucket', 'bitcoin', 'bitcoincash', 'bitcoinsv', 'bitcomet',
                     'bitdefender', 'bitly', 'bitrise', 'bittorrent', 'bitwarden', 'bitwig', 'blackberry',
                     'blackmagicdesign', 'blazemeter', 'blazor', 'blender', 'blockbench', 'blockchaindotcom', 'blogger',
                     'bloglovin', 'blueprint', 'bluesky', 'bluesound', 'bluetooth', 'bmcsoftware', 'bmw', 'bnbchain',
                     'boardgamegeek', 'boat', 'boehringeringelheim', 'boeing', 'bombardier', 'bookalope', 'bookbub',
                     'bookmeter', 'bookmyshow', 'bookstack', 'boost', 'boosty', 'boots', 'bootstrap', 'borgbackup',
                     'bosch', 'bose', 'botblecms', 'boulanger', 'bower', 'box', 'boxysvg', 'braintree', 'brandfolder',
                     'brave', 'breaker', 'brenntag', 'brevo', 'brex', 'bricks', 'britishairways', 'broadcom', 'bsd',
                     'bspwm', 'bt', 'buddy', 'budibase', 'buefy', 'buffer', 'bugatti', 'bugcrowd', 'bugsnag',
                     'buildkite', 'bukalapak', 'bulma', 'bun', 'bungie', 'bunq', 'burgerking', 'burpsuite', 'burton',
                     'buymeacoffee', 'buzzfeed', 'bvg', 'byjus', 'bytedance', 'c', 'cachet', 'caddy', 'cadillac',
                     'cafepress', 'caffeine', 'cairographics', 'cairometro', 'cakephp', 'calendly', 'campaignmonitor',
                     'camunda', 'canonical', 'canva', 'canvas', 'capacitor', 'cardano', 'carlsberggroup', 'carrd',
                     'carrefour', 'carthrottle', 'carto', 'cashapp', 'castbox', 'castorama', 'castro', 'caterpillar',
                     'cbc', 'cbs', 'ccleaner', 'cdprojekt', 'celery', 'celestron', 'centos', 'ceph', 'cesium', 'chai',
                     'chainguard', 'chainlink', 'chakraui', 'channel4', 'charles', 'chartdotjs', 'chartmogul', 'chase',
                     'chatbot', 'chatwoot', 'checkio', 'checkmarx', 'checkmk', 'chedraui', 'chef', 'chemex',
                     'chevrolet', 'chianetwork', 'chinaeasternairlines', 'chinasouthernairlines', 'chocolatey',
                     'chromatic', 'chromecast', 'chrysler', 'chupachups', 'cilium', 'cinema4d', 'circle', 'circleci',
                     'circuitverse', 'cirrusci', 'cisco', 'citrix', 'citroen', 'civicrm', 'civo', 'ckeditor4',
                     'clarifai', 'claris', 'clarivate', 'clerk', 'clevercloud', 'clickhouse', 'clickup', 'clion',
                     'cliqz', 'clockify', 'clojure', 'cloud66', 'cloudbees', 'cloudcannon', 'cloudera', 'cloudflare',
                     'cloudflarepages', 'cloudfoundry', 'cloudinary', 'cloudron', 'cloudsmith', 'cloudways',
                     'clubhouse', 'clyp', 'cmake', 'cncf', 'cnet', 'cnn', 'cocacola', 'cockpit', 'cockroachlabs',
                     'cocoapods', 'cocos', 'coda', 'codacy', 'codeberg', 'codeblocks', 'codecademy', 'codeceptjs',
                     'codechef', 'codeclimate', 'codecov', 'codefactor', 'codeforces', 'codefresh', 'codeigniter',
                     'codeium', 'codemagic', 'codementor', 'codemirror', 'codenewbie', 'codepen', 'codeproject',
                     'codersrank', 'coderwall', 'codesandbox', 'codeship', 'codesignal', 'codestream', 'codewars',
                     'codingame', 'codingninjas', 'codio', 'coffeescript', 'coggle', 'cognizant', 'coil', 'coinbase',
                     'coinmarketcap', 'comicfury', 'commerzbank', 'commitlint', 'commodore', 'commonworkflowlanguage',
                     'compilerexplorer', 'composer', 'comptia', 'comsol', 'conan', 'concourse', 'condaforge', 'conekta',
                     'confluence', 'construct3', 'consul', 'contactlesspayment', 'containerd', 'contao', 'contentful',
                     'contentstack', 'contributorcovenant', 'conventionalcommits', 'convertio', 'cookiecutter',
                     'coolermaster', 'coop', 'coppel', 'cora', 'coronaengine', 'coronarenderer', 'corsair', 'couchbase',
                     'counterstrike', 'countingworkspro', 'coursera', 'coveralls', 'cpanel', 'cplusplus',
                     'cplusplusbuilder', 'craftcms', 'craftsman', 'cratedb', 'crayon', 'creality', 'createreactapp',
                     'creativecommons', 'creativetechnology', 'credly', 'crehana', 'crewunited', 'criticalrole',
                     'crowdin', 'crowdsource', 'crunchbase', 'crunchyroll', 'cryengine', 'crystal', 'csharp', 'css3',
                     'cssmodules', 'csswizardry', 'cts', 'cucumber', 'cultura', 'curl', 'curseforge', 'customink',
                     'cyberdefenders', 'cycling74', 'cypress', 'cytoscapedotjs', 'd', 'd3dotjs', 'dacia', 'daf',
                     'dailydotdev', 'dailymotion', 'daimler', 'daisyui', 'dapr', 'darkreader', 'dart', 'darty',
                     'daserste', 'dash', 'dashlane', 'dask', 'dassaultsystemes', 'databricks', 'datacamp', 'datadog',
                     'datadotai', 'datagrip', 'dataiku', 'datastax', 'dataverse', 'datefns', 'datocms', 'datto',
                     'davinciresolve', 'dazn', 'dbeaver', 'dblp', 'dbt', 'dcentertainment', 'debian', 'decapcms',
                     'dedge', 'deepcool', 'deepgram', 'deepin', 'deepl', 'deepnote', 'delicious', 'deliveroo', 'dell',
                     'delonghi', 'delphi', 'delta', 'deluge', 'deno', 'denon', 'dependabot', 'dependencycheck',
                     'depositphotos', 'derspiegel', 'designernews', 'deutschebahn', 'deutschebank', 'deutschepost',
                     'devdotto', 'devexpress', 'deviantart', 'devpost', 'devrant', 'dgraph', 'dhl', 'diagramsdotnet',
                     'dialogflow', 'diaspora', 'digg', 'digikeyelectronics', 'digitalocean', 'dinersclub', 'dior',
                     'directus', 'discogs', 'discord', 'discourse', 'discover', 'disqus', 'disroot', 'distrokid',
                     'django', 'dji', 'dlib', 'dlna', 'dm', 'docker', 'docsdotrs', 'docsify', 'docusaurus', 'docusign',
                     'dogecoin', 'doi', 'dolby', 'doordash', 'dotenv', 'dotnet', 'douban', 'doubanread', 'dovecot',
                     'doxygen', 'dpd', 'dragonframe', 'draugiemdotlv', 'dreamstime', 'dribbble', 'drizzle', 'drone',
                     'drooble', 'dropbox', 'drupal', 'dsautomobiles', 'dts', 'dtube', 'ducati', 'duckdb', 'duckduckgo',
                     'dungeonsanddragons', 'dunked', 'dunzo', 'duolingo', 'dvc', 'dwavesystems', 'dwm', 'dynamics365',
                     'dynatrace', 'e', 'e3', 'ea', 'eagle', 'easyeda', 'easyjet', 'ebay', 'ebox', 'eclipseadoptium',
                     'eclipseche', 'eclipseide', 'eclipsejetty', 'eclipsemosquitto', 'eclipsevertdotx', 'ecovacs',
                     'edeka', 'edgeimpulse', 'editorconfig', 'edotleclerc', 'educative', 'edx', 'egghead', 'egnyte',
                     'eight', 'eightsleep', 'ejs', 'elastic', 'elasticcloud', 'elasticsearch', 'elasticstack', 'elavon',
                     'electron', 'electronbuilder', 'electronfiddle', 'element', 'elementary', 'elementor', 'eleventy',
                     'elgato', 'elixir', 'eljueves', 'ello', 'elm', 'elsevier', 'embarcadero', 'embark', 'emberdotjs',
                     'emby', 'emirates', 'emlakjet', 'empirekred', 'engadget', 'enpass', 'enterprisedb', 'envato',
                     'envoyproxy', 'epel', 'epicgames', 'epson', 'equinixmetal', 'ericsson', 'erlang', 'erpnext',
                     'esbuild', 'esea', 'eslgaming', 'eslint', 'esotericsoftware', 'esphome', 'espressif', 'esri',
                     'etcd', 'ethereum', 'ethiopianairlines', 'etihadairways', 'etsy', 'eventbrite', 'eventstore',
                     'evernote', 'excalidraw', 'exercism', 'exordo', 'exoscale', 'expedia', 'expensify',
                     'expertsexchange', 'expo', 'express', 'expressvpn', 'eyeem', 'f1', 'f5', 'facebook',
                     'facebookgaming', 'facebooklive', 'faceit', 'facepunch', 'fairphone', 'falco', 'falcon', 'fampay',
                     'fandango', 'fandom', 'fanfou', 'fantom', 'farcaster', 'fareharbor', 'farfetch', 'fastapi',
                     'fastify', 'fastlane', 'fastly', 'fathom', 'fauna', 'favro', 'fdroid', 'feathub', 'fedex',
                     'fedora', 'feedly', 'ferrari', 'ferrarinv', 'ferretdb', 'ffmpeg', 'fi', 'fiat', 'fidoalliance',
                     'fifa', 'fig', 'figma', 'figshare', 'fila', 'filedotio', 'files', 'filezilla', 'fineco', 'fing',
                     'firebase', 'firefish', 'fireflyiii', 'firefox', 'firefoxbrowser', 'fireship', 'firewalla',
                     'first', 'fitbit', 'fite', 'fivem', 'fiverr', 'flask', 'flat', 'flathub', 'flatpak', 'flattr',
                     'flickr', 'flightaware', 'flipboard', 'flipkart', 'floatplane', 'flood', 'fluentbit', 'fluentd',
                     'fluke', 'flutter', 'flux', 'fluxus', 'flyway', 'fmod', 'fnac', 'folium', 'fonoma', 'fontawesome',
                     'fontbase', 'fontforge', 'foobar2000', 'foodpanda', 'ford', 'forgejo', 'formspree', 'formstack',
                     'fortinet', 'fortran', 'fossa', 'fossilscm', 'foursquare', 'foursquarecityguide', 'fox', 'foxtel',
                     'fozzy', 'framer', 'framework', 'framework7', 'franprix', 'frappe', 'fraunhofergesellschaft',
                     'freebsd', 'freecodecamp', 'freedesktopdotorg', 'freelancer', 'freenas', 'freepik',
                     'frontendmentor', 'frontify', 'fsecure', 'fsharp', 'fubo', 'fugacloud', 'fujifilm', 'fujitsu',
                     'funimation', 'furaffinity', 'furrynetwork', 'futurelearn', 'g2', 'g2a', 'galaxus', 'gameandwatch',
                     'gamebanana', 'gamedeveloper', 'gamejolt', 'gameloft', 'gamemaker', 'garmin', 'gatling', 'gatsby',
                     'gdal', 'geant', 'geeksforgeeks', 'generalelectric', 'generalmotors', 'genius', 'gentoo',
                     'geocaching', 'geopandas', 'gerrit', 'getx', 'ghost', 'ghostery', 'gimp', 'gin', 'giphy', 'git',
                     'gitbook', 'gitconnected', 'gitea', 'gitee', 'gitextensions', 'github', 'githubactions',
                     'githubcopilot', 'githubpages', 'githubsponsors', 'gitignoredotio', 'gitkraken', 'gitlab',
                     'gitlfs', 'gitpod', 'gitter', 'glassdoor', 'glide', 'glitch', 'globus', 'glovo', 'gmail', 'gnome',
                     'gnometerminal', 'gnu', 'gnubash', 'gnuemacs', 'gnuicecat', 'gnuprivacyguard', 'gnusocial', 'go',
                     'gocd', 'godaddy', 'godotengine', 'gofundme', 'gogdotcom', 'gojek', 'goland', 'goldenline',
                     'goldmansachs', 'goodreads', 'google', 'googleadmob', 'googleads', 'googleadsense',
                     'googleanalytics', 'googleappsscript', 'googleassistant', 'googlebard', 'googlebigquery',
                     'googlebigtable', 'googlecalendar', 'googlecampaignmanager360', 'googlecardboard', 'googlechat',
                     'googlechrome', 'googlechronicle', 'googleclassroom', 'googlecloud', 'googlecloudcomposer',
                     'googlecloudspanner', 'googlecloudstorage', 'googlecolab', 'googlecontaineroptimizedos',
                     'googledataflow', 'googledataproc', 'googledatastudio', 'googledisplayandvideo360', 'googledocs',
                     'googledomains', 'googledrive', 'googleearth', 'googleearthengine', 'googlefit', 'googlefonts',
                     'googleforms', 'googlegemini', 'googlehangouts', 'googlehome', 'googlekeep', 'googlelens',
                     'googlemaps', 'googlemarketingplatform', 'googlemeet', 'googlemessages', 'googlemybusiness',
                     'googlenearby', 'googlenews', 'googleoptimize', 'googlepay', 'googlephotos', 'googleplay',
                     'googlepodcasts', 'googlepubsub', 'googlescholar', 'googlesearchconsole', 'googlesheets',
                     'googleslides', 'googlestreetview', 'googletagmanager', 'googletasks', 'googletranslate',
                     'gotomeeting', 'grab', 'gradle', 'gradleplaypublisher', 'grafana', 'grammarly', 'grandfrais',
                     'grapheneos', 'graphite', 'graphql', 'grav', 'gravatar', 'graylog', 'greasyfork', 'greatlearning',
                     'greenhouse', 'greensock', 'griddotai', 'gridsome', 'groupme', 'groupon', 'grubhub', 'grunt',
                     'gsk', 'gsmarenadotcom', 'gstreamer', 'gtk', 'guangzhoumetro', 'guilded', 'gulp', 'gumroad',
                     'gumtree', 'gunicorn', 'gurobi', 'gutenberg', 'h3', 'habr', 'hackaday', 'hackclub', 'hackerearth',
                     'hackernoon', 'hackerone', 'hackerrank', 'hackster', 'hackthebox', 'hal', 'handlebarsdotjs',
                     'handm', 'handshake', 'handshake_protocol', 'happycow', 'harbor', 'harmonyos', 'hashicorp',
                     'hashnode', 'haskell', 'hasura', 'hatenabookmark', 'haveibeenpwned', 'haxe', 'hbo', 'hcl',
                     'hdfcbank', 'headlessui', 'headphonezone', 'headspace', 'hearth', 'hearthisdotat', 'hedera',
                     'helium', 'hellofresh', 'hellyhansen', 'helm', 'helpdesk', 'helpscout', 'hepsiemlak', 'here',
                     'heroku', 'hetzner', 'hevy', 'hexlet', 'hexo', 'hey', 'hibernate', 'hibob', 'hilton',
                     'hiltonhotelsandresorts', 'hitachi', 'hive', 'hivemq', 'hive_blockchain', 'homeadvisor',
                     'homeassistant', 'homeassistantcommunitystore', 'homebrew', 'homebridge', 'homify', 'honda',
                     'honey', 'hono', 'honor', 'hootsuite', 'hoppscotch', 'hostinger', 'hotelsdotcom', 'hotjar',
                     'hotwire', 'houdini', 'houzz', 'hp', 'hsbc', 'html5', 'htmlacademy', 'htmx', 'htop', 'httpie',
                     'huawei', 'hubspot', 'hugo', 'humblebundle', 'hungryjacks', 'husqvarna', 'hyper', 'hyperskill',
                     'hypothesis', 'hyundai', 'i18next', 'i3', 'iata', 'ibeacon', 'iberia', 'ibm', 'ibmcloud',
                     'ibmwatson', 'iced', 'iceland', 'icicibank', 'icinga', 'icloud', 'icomoon', 'icon', 'iconfinder',
                     'iconify', 'iconjar', 'icons8', 'icq', 'ieee', 'ifixit', 'ifood', 'ifttt', 'igdb', 'ign',
                     'iheartradio', 'ikea', 'iledefrancemobilites', 'imagedotsc', 'imagej', 'imdb', 'imgur', 'immer',
                     'immich', 'imou', 'improvmx', 'indeed', 'indiehackers', 'indigo', 'inertia', 'infiniti',
                     'influxdb', 'infoq', 'informatica', 'infosys', 'infracost', 'ingress', 'inkdrop', 'inkscape',
                     'insomnia', 'inspire', 'insta360', 'instacart', 'instagram', 'instapaper', 'instatus',
                     'instructables', 'instructure', 'integromat', 'intel', 'intellijidea',
                     'interactiondesignfoundation', 'interactjs', 'interbase', 'intercom', 'intermarche',
                     'internetarchive', 'internetcomputer', 'internetexplorer', 'intigriti', 'intuit', 'invision',
                     'invoiceninja', 'iobroker', 'ionic', 'ionos', 'ios', 'iota', 'ipfs', 'iris', 'irobot', 'isc2',
                     'issuu', 'istio', 'itchdotio', 'iterm2', 'itunes', 'itvx', 'iveco', 'jabber', 'jaeger', 'jaguar',
                     'jamboard', 'jameson', 'jamstack', 'jasmine', 'javascript', 'jbl', 'jcb', 'jeep', 'jekyll',
                     'jellyfin', 'jenkins', 'jest', 'jet', 'jetblue', 'jetbrains', 'jetpackcompose', 'jfrog',
                     'jfrogpipelines', 'jinja', 'jira', 'jirasoftware', 'jitpack', 'jitsi', 'johndeere', 'joomla',
                     'joplin', 'jordan', 'jouav', 'jovian', 'jpeg', 'jquery', 'jrgroup', 'jsdelivr', 'jsfiddle', 'json',
                     'jsonwebtokens', 'jss', 'juce', 'juejin', 'juke', 'julia', 'junipernetworks', 'junit5', 'jupyter',
                     'justeat', 'justgiving', 'k3s', 'k6', 'kaggle', 'kahoot', 'kaios', 'kakao', 'kakaotalk',
                     'kalilinux', 'kamailio', 'kaniko', 'karlsruherverkehrsverbund', 'kasasmart', 'kashflow',
                     'kaspersky', 'katacoda', 'katana', 'kaufland', 'kde', 'kdenlive', 'kedro', 'keenetic',
                     'keepachangelog', 'keepassxc', 'kentico', 'keras', 'keybase', 'keycdn', 'keystone', 'kfc',
                     'khanacademy', 'khronosgroup', 'kia', 'kibana', 'kicad', 'kick', 'kickstarter', 'kik',
                     'kingstontechnology', 'kinopoisk', 'kinsta', 'kirby', 'kit', 'kitsu', 'klarna', 'klm', 'klook',
                     'knative', 'knexdotjs', 'knime', 'knowledgebase', 'known', 'koa', 'koc', 'kodak', 'kodi', 'kofax',
                     'kofi', 'komoot', 'konami', 'kong', 'kongregate', 'konva', 'kotlin', 'koyeb', 'krita', 'ktm',
                     'kuaishou', 'kubernetes', 'kubuntu', 'kucoin', 'kuma', 'kununu', 'kuula', 'kx', 'kyocera',
                     'labview', 'lada', 'lamborghini', 'landrover', 'lapce', 'laragon', 'laravel', 'laravelhorizon',
                     'laravelnova', 'lastdotfm', 'lastpass', 'latex', 'launchpad', 'lazarus', 'lbry', 'leaderprice',
                     'leaflet', 'leagueoflegends', 'leanpub', 'leetcode', 'legacygames', 'leica', 'lemmy', 'lenovo',
                     'lens', 'leptos', 'lequipe', 'lerna', 'leroymerlin', 'leslibraires', 'less', 'letsencrypt',
                     'letterboxd', 'levelsdotfyi', 'lg', 'liberadotchat', 'liberapay', 'librariesdotio', 'librarything',
                     'libreoffice', 'libreofficebase', 'libreofficecalc', 'libreofficedraw', 'libreofficeimpress',
                     'libreofficemath', 'libreofficewriter', 'libuv', 'lichess', 'lidl', 'lifx', 'lightburn',
                     'lighthouse', 'lightning', 'line', 'lineageos', 'linear', 'lining', 'linkedin', 'linkerd',
                     'linkfire', 'linksys', 'linktree', 'lintcode', 'linux', 'linuxcontainers', 'linuxfoundation',
                     'linuxmint', 'linuxprofessionalinstitute', 'linuxserver', 'lionair', 'liquibase', 'lit',
                     'litecoin', 'litiengine', 'livechat', 'livejournal', 'livewire', 'llvm', 'lmms', 'local', 'lodash',
                     'logitech', 'logitechg', 'logmein', 'logseq', 'logstash', 'looker', 'loom', 'loop', 'loopback',
                     'lootcrate', 'lospec', 'lotpolishairlines', 'ltspice', 'lua', 'lubuntu', 'lucid', 'ludwig',
                     'lufthansa', 'lumen', 'lunacy', 'lutris', 'lydia', 'lyft', 'maas', 'macos', 'macpaw', 'macys',
                     'magasinsu', 'magento', 'magic', 'magisk', 'mahindra', 'mailchimp', 'maildotcom', 'maildotru',
                     'mailgun', 'mailtrap', 'majorleaguehacking', 'make', 'makerbot', 'mambaui', 'mamp', 'man',
                     'manageiq', 'manjaro', 'mantine', 'mapbox', 'maplibre', 'mariadb', 'mariadbfoundation', 'markdown',
                     'marketo', 'marko', 'marriott', 'marvelapp', 'maserati', 'mastercard', 'mastercomfig', 'mastodon',
                     'materialdesign', 'materialdesignicons', 'materialformkdocs', 'matillion', 'matomo', 'matrix',
                     'matterdotjs', 'mattermost', 'matternet', 'mautic', 'max', 'maxplanckgesellschaft', 'maytag',
                     'mazda', 'mcafee', 'mcdonalds', 'mclaren', 'mdbook', 'mdnwebdocs', 'mdx', 'mediafire',
                     'mediamarkt', 'mediatek', 'medibangpaint', 'medium', 'medusa', 'meetup', 'mega', 'meilisearch',
                     'meituan', 'mendeley', 'mentorcruise', 'mercadopago', 'mercedes', 'merck', 'mercurial', 'mermaid',
                     'messenger', 'meta', 'metabase', 'metacritic', 'metafilter', 'metasploit', 'meteor', 'metro',
                     'metrodelaciudaddemexico', 'metrodemadrid', 'metrodeparis', 'mewe', 'mg', 'microbit',
                     'microdotblog', 'microeditor', 'microgenetics', 'micropython', 'microsoft', 'microsoftacademic',
                     'microsoftaccess', 'microsoftazure', 'microsoftbing', 'microsoftedge', 'microsoftexcel',
                     'microsoftexchange', 'microsoftonedrive', 'microsoftonenote', 'microsoftoutlook',
                     'microsoftpowerpoint', 'microsoftsharepoint', 'microsoftsqlserver', 'microsoftstore',
                     'microsoftteams', 'microsofttranslator', 'microsoftvisio', 'microsoftword', 'microstation',
                     'microstrategy', 'midi', 'mikrotik', 'milanote', 'milvus', 'minds', 'minecraft', 'minetest',
                     'mini', 'minio', 'minutemailer', 'miraheze', 'miro', 'misskey', 'mitsubishi', 'mix', 'mixcloud',
                     'mixpanel', 'mlb', 'mlflow', 'mobx', 'mobxstatetree', 'mocha', 'mockserviceworker', 'modin',
                     'modrinth', 'modx', 'mojangstudios', 'moleculer', 'momenteo', 'monero', 'moneygram', 'mongodb',
                     'mongoose', 'mongoosedotws', 'monica', 'monkeytie', 'monkeytype', 'monogame', 'monoprix',
                     'monster', 'monzo', 'moo', 'moodle', 'moonrepo', 'moqups', 'morrisons', 'moscowmetro', 'motorola',
                     'mozilla', 'mpv', 'mqtt', 'msi', 'msibusiness', 'mta', 'mtr', 'mubi', 'mui', 'mulesoft', 'muller',
                     'multisim', 'mumble', 'muo', 'mural', 'musescore', 'musicbrainz', 'mxlinux', 'myanimelist',
                     'myget', 'myob', 'myspace', 'mysql', 'n26', 'namebase', 'namecheap', 'namemc', 'namesilo',
                     'namuwiki', 'nano', 'nasa', 'nationalgrid', 'nationalrail', 'nativescript', 'natsdotio', 'naver',
                     'nba', 'nbb', 'nbc', 'ndr', 'near', 'nec', 'neo4j', 'neovim', 'neptune', 'nestjs', 'netapp',
                     'netbsd', 'netcup', 'netdata', 'neteasecloudmusic', 'netflix', 'netgear', 'netlify', 'nette',
                     'netto', 'neutralinojs', 'newbalance', 'newegg', 'newjapanprowrestling', 'newrelic',
                     'newyorktimes', 'nextbilliondotai', 'nextcloud', 'nextdns', 'nextdoor', 'nextdotjs', 'nextra',
                     'nextui', 'nexusmods', 'nfc', 'nginx', 'nginxproxymanager', 'ngrok', 'ngrx', 'nhl', 'niantic',
                     'niconico', 'nike', 'nikon', 'nim', 'nintendo', 'nintendo3ds', 'nintendogamecube',
                     'nintendonetwork', 'nintendoswitch', 'nissan', 'nixos', 'nodedotjs', 'nodemon', 'nodered', 'nokia',
                     'nomad', 'norco', 'nordicsemiconductor', 'nordvpn', 'normalizedotcss', 'norton', 'norwegian',
                     'notepadplusplus', 'notion', 'notist', 'nounproject', 'novu', 'now', 'npm', 'nrwl', 'nsis',
                     'nubank', 'nucleo', 'nuget', 'nuke', 'numba', 'numpy', 'nunjucks', 'nutanix', 'nuxtdotjs',
                     'nvidia', 'nx', 'nxp', 'nzxt', 'observable', 'obsidian', 'obsstudio', 'ocaml', 'oclif',
                     'octanerender', 'octave', 'octobercms', 'octoprint', 'octopusdeploy', 'oculus', 'odnoklassniki',
                     'odoo', 'odysee', 'ohdear', 'okcupid', 'okta', 'oneplus', 'onlyfans', 'onlyoffice', 'onnx',
                     'onstar', 'opel', 'openaccess', 'openai', 'openaigym', 'openapiinitiative', 'openbadges',
                     'openbsd', 'openbugbounty', 'opencollective', 'opencontainersinitiative', 'opencv', 'openfaas',
                     'opengl', 'openhab', 'openid', 'openjdk', 'openlayers', 'openmined', 'opennebula', 'openproject',
                     'openscad', 'opensea', 'opensearch', 'opensourcehardware', 'opensourceinitiative', 'openssl',
                     'openstack', 'openstreetmap', 'opensuse', 'opentelemetry', 'opentext', 'opentofu', 'openverse',
                     'openvpn', 'openwrt', 'openzeppelin', 'openzfs', 'opera', 'operagx', 'opnsense', 'oppo',
                     'opsgenie', 'opslevel', 'oracle', 'orange', 'orcid', 'oreilly', 'org', 'origin', 'osano', 'osf',
                     'osgeo', 'oshkosh', 'osmc', 'osu', 'otto', 'overcast', 'overleaf', 'ovh', 'owasp', 'owncloud',
                     'oxygen', 'oyo', 'p5dotjs', 'packagist', 'packer', 'packt', 'paddle', 'paddlepaddle', 'paddypower',
                     'pagekit', 'pagerduty', 'pagespeedinsights', 'pagseguro', 'palantir', 'paloaltonetworks',
                     'paloaltosoftware', 'panasonic', 'pandas', 'pandora', 'pantheon', 'paperlessngx', 'paperspace',
                     'paperswithcode', 'paramountplus', 'paritysubstrate', 'parsedotly', 'passport', 'pastebin',
                     'patreon', 'paychex', 'payhip', 'payloadcms', 'payoneer', 'paypal', 'paytm', 'pcgamingwiki', 'pdm',
                     'pdq', 'peakdesign', 'pearson', 'peerlist', 'peertube', 'pegasusairlines', 'pelican', 'peloton',
                     'penny', 'penpot', 'percy', 'perforce', 'perl', 'perplexity', 'persistent', 'personio',
                     'petsathome', 'peugeot', 'pexels', 'pfsense', 'phabricator', 'philipshue', 'phoenixframework',
                     'phonepe', 'phosphoricons', 'photobucket', 'photocrowd', 'photon', 'photopea', 'php', 'phpmyadmin',
                     'phpstorm', 'piaggiogroup', 'piapro', 'picardsurgeles', 'picartodottv', 'picnic', 'picpay',
                     'picxy', 'pihole', 'pimcore', 'pinboard', 'pinescript', 'pinetwork', 'pingdom', 'pinterest',
                     'pioneerdj', 'piped', 'pipx', 'pivotaltracker', 'piwigo', 'pix', 'pixabay', 'pixelfed', 'pixiv',
                     'pkgsrc', 'planet', 'planetscale', 'plangrid', 'platformdotsh', 'platformio', 'platzi',
                     'plausibleanalytics', 'playcanvas', 'playerdotme', 'playerfm', 'playstation', 'playstation2',
                     'playstation3', 'playstation4', 'playstation5', 'playstationvita', 'playwright', 'pleroma',
                     'plesk', 'plex', 'plotly', 'pluralsight', 'plurk', 'pluscodes', 'pm2', 'pnpm', 'pocket',
                     'pocketbase', 'pocketcasts', 'podcastaddict', 'podcastindex', 'podman', 'poe', 'poetry', 'pointy',
                     'pokemon', 'polars', 'polestar', 'polkadot', 'poly', 'polygon', 'polymerproject', 'polywork',
                     'pond5', 'popos', 'porkbun', 'porsche', 'portainer', 'portswigger', 'postcss', 'postgresql',
                     'posthog', 'postman', 'postmates', 'powerapps', 'powerautomate', 'powerbi', 'powerfx',
                     'powerpages', 'powers', 'powershell', 'powervirtualagents', 'prdotco', 'preact', 'precommit',
                     'prefect', 'premierleague', 'prepbytes', 'prestashop', 'presto', 'prettier', 'pretzel',
                     'prevention', 'prezi', 'prime', 'primevideo', 'printables', 'prisma', 'prismic', 'privatedivision',
                     'privateinternetaccess', 'probot', 'processingfoundation', 'processwire', 'producthunt', 'progate',
                     'progress', 'prometheus', 'prosieben', 'proteus', 'protocolsdotio', 'protodotio', 'proton',
                     'protoncalendar', 'protondb', 'protondrive', 'protonmail', 'protonvpn', 'protools', 'protractor',
                     'proxmox', 'pterodactyl', 'pubg', 'publons', 'pubmed', 'pug', 'pulumi', 'puma', 'puppet',
                     'puppeteer', 'purescript', 'purgecss', 'purism', 'pushbullet', 'pusher', 'pwa', 'pycharm', 'pycqa',
                     'pydantic', 'pyg', 'pypi', 'pypy', 'pyscaffold', 'pysyft', 'pytest', 'python', 'pythonanywhere',
                     'pytorch', 'pyup', 'qantas', 'qase', 'qatarairways', 'qbittorrent', 'qemu', 'qgis', 'qi', 'qiita',
                     'qiskit', 'qiwi', 'qlik', 'qmk', 'qnap', 'qt', 'qualcomm', 'qualtrics', 'qualys', 'quantcast',
                     'quantconnect', 'quarkus', 'quasar', 'qubesos', 'quest', 'quickbooks', 'quicklook', 'quicktime',
                     'quicktype', 'quip', 'quora', 'qwant', 'qwiklabs', 'qzone', 'r', 'r3', 'rabbitmq', 'racket',
                     'radar', 'radarr', 'radiopublic', 'radixui', 'radstudio', 'railway', 'rainmeter', 'rakuten', 'ram',
                     'rancher', 'rapid', 'rarible', 'rasa', 'raspberrypi', 'ravelry', 'ray', 'raycast', 'raylib',
                     'razer', 'razorpay', 'react', 'reacthookform', 'reactiveresume', 'reactivex', 'reactos',
                     'reactquery', 'reactrouter', 'reacttable', 'readdotcv', 'readme', 'readthedocs', 'realm', 'reason',
                     'reasonstudios', 'recoil', 'red', 'redbubble', 'redbull', 'reddit', 'redhat', 'redhatopenshift',
                     'redis', 'redmine', 'redox', 'redux', 'reduxsaga', 'redwoodjs', 'reebok', 'refine', 'relay',
                     'relianceindustrieslimited', 'remark', 'remedyentertainment', 'remix', 'renault', 'render',
                     'renovatebot', 'renpy', 'renren', 'replit', 'republicofgamers', 'rescript', 'rescuetime',
                     'researchgate', 'resend', 'resharper', 'resurrectionremixos', 'retool', 'retroarch', 'retropie',
                     'revanced', 'revealdotjs', 'reverbnation', 'revoltdotchat', 'revolut', 'revue', 'rewe', 'rezgo',
                     'rhinoceros', 'rider', 'rimacautomobili', 'ring', 'riotgames', 'ripple', 'riscv', 'riseup',
                     'ritzcarlton', 'rive', 'roadmapdotsh', 'roamresearch', 'robinhood', 'roblox', 'robloxstudio',
                     'robotframework', 'rocketdotchat', 'rocksdb', 'rockstargames', 'rockwellautomation', 'rockylinux',
                     'roku', 'roll20', 'rollsroyce', 'rollupdotjs', 'rome', 'roon', 'rootme', 'roots', 'rootsbedrock',
                     'rootssage', 'ros', 'rossmann', 'rotaryinternational', 'rottentomatoes', 'roundcube', 'rsocket',
                     'rss', 'rstudio', 'rte', 'rtl', 'rtlzwei', 'rtm', 'rubocop', 'ruby', 'rubygems', 'rubyonrails',
                     'rubysinatra', 'ruff', 'rumahweb', 'rumble', 'rundeck', 'runkeeper', 'runkit', 'runrundotit',
                     'rust', 'rustdesk', 'rxdb', 'ryanair', 'rye', 's7airlines', 'sabanci', 'safari', 'sage',
                     'sahibinden', 'sailfishos', 'sailsdotjs', 'salesforce', 'salla', 'saltproject', 'samsclub',
                     'samsung', 'samsungpay', 'sandisk', 'sanfranciscomunicipalrailway', 'sanic', 'sanity',
                     'saopaulometro', 'sap', 'sass', 'sat1', 'satellite', 'saturn', 'saucelabs', 'saudia', 'scala',
                     'scaleway', 'scania', 'schneiderelectric', 'scikitlearn', 'scipy', 'scopus', 'scpfoundation',
                     'scrapbox', 'scrapy', 'scratch', 'screencastify', 'scribd', 'scrimba', 'scrollreveal',
                     'scrumalliance', 'scrutinizerci', 'scylladb', 'seagate', 'searxng', 'seat', 'seatgeek',
                     'securityscorecard', 'sefaria', 'sega', 'selenium', 'sellfy', 'semanticrelease', 'semanticscholar',
                     'semanticui', 'semanticuireact', 'semanticweb', 'semaphoreci', 'semrush', 'semver', 'sencha',
                     'sennheiser', 'sensu', 'sentry', 'sepa', 'sequelize', 'serverfault', 'serverless', 'session',
                     'sessionize', 'setapp', 'sfml', 'shadcnui', 'shadow', 'shanghaimetro', 'sharex', 'sharp', 'shazam',
                     'shell', 'shelly', 'shenzhenmetro', 'shieldsdotio', 'shikimori', 'shopee', 'shopify', 'shopware',
                     'shortcut', 'shotcut', 'showpad', 'showtime', 'showwcase', 'shutterstock', 'sidekiq', 'sidequest',
                     'siemens', 'sifive', 'signal', 'similarweb', 'simkl', 'simpleanalytics', 'simpleicons',
                     'simplelogin', 'simplenote', 'sinaweibo', 'singaporeairlines', 'singlestore', 'sitecore',
                     'sitepoint', 'siyuan', 'skaffold', 'sketch', 'sketchfab', 'sketchup', 'skillshare', 'skoda', 'sky',
                     'skynet', 'skypack', 'skype', 'skypeforbusiness', 'skyrock', 'slack', 'slackware', 'slashdot',
                     'slickpic', 'slides', 'slideshare', 'slint', 'smart', 'smartthings', 'smashdotgg',
                     'smashingmagazine', 'smrt', 'smugmug', 'snapchat', 'snapcraft', 'sncf', 'snowflake', 'snowpack',
                     'snyk', 'socialblade', 'society6', 'socketdotio', 'softpedia', 'sogou', 'solana', 'solid',
                     'solidity', 'sololearn', 'solus', 'sonar', 'sonarcloud', 'sonarlint', 'sonarqube', 'sonarr',
                     'sonatype', 'songkick', 'songoda', 'sonicwall', 'sonos', 'sony', 'soriana', 'soundcharts',
                     'soundcloud', 'sourceengine', 'sourceforge', 'sourcehut', 'sourcetree', 'southwestairlines',
                     'spacemacs', 'spacex', 'spacy', 'sparkar', 'sparkasse', 'sparkfun', 'sparkpost', 'spdx',
                     'speakerdeck', 'spectrum', 'speedtest', 'speedypage', 'sphinx', 'spigotmc', 'spine', 'spinnaker',
                     'spinrilla', 'splunk', 'spoj', 'spond', 'spotify', 'spotlight', 'spreadshirt', 'spreaker',
                     'spring', 'springboot', 'springsecurity', 'spring_creators', 'spyderide', 'sqlalchemy', 'sqlite',
                     'square', 'squareenix', 'squarespace', 'srgssr', 'ssrn', 'sst', 'stackbit', 'stackblitz',
                     'stackedit', 'stackexchange', 'stackhawk', 'stackoverflow', 'stackpath', 'stackshare', 'stadia',
                     'staffbase', 'stagetimer', 'standardjs', 'standardresume', 'starbucks', 'stardock', 'starlingbank',
                     'starship', 'startrek', 'starz', 'statamic', 'statuspage', 'statuspal', 'steam', 'steamdb',
                     'steamdeck', 'steamworks', 'steelseries', 'steem', 'steemit', 'steinberg', 'stellar', 'stencyl',
                     'stimulus', 'stitcher', 'stmicroelectronics', 'stockx', 'stopstalk', 'storyblok', 'storybook',
                     'strapi', 'strava', 'streamlabs', 'streamlit', 'streamrunners', 'stripe', 'strongswan', 'stryker',
                     'stubhub', 'studio3t', 'studyverse', 'styledcomponents', 'stylelint', 'styleshare', 'stylus',
                     'subaru', 'sublimetext', 'substack', 'subtitleedit', 'subversion', 'suckless', 'sumologic',
                     'supabase', 'supercrease', 'supermicro', 'superuser', 'surrealdb', 'surveymonkey', 'suse',
                     'suzuki', 'svelte', 'svg', 'svgdotjs', 'svgo', 'swagger', 'swarm', 'swc', 'swift', 'swiggy',
                     'swiper', 'swr', 'symantec', 'symbolab', 'symfony', 'symphony', 'sympy', 'synology', 'system76',
                     'tabelog', 'tableau', 'tablecheck', 'tacobell', 'tado', 'taichigraphics', 'taichilang', 'tails',
                     'tailwindcss', 'taketwointeractivesoftware', 'talend', 'talenthouse', 'tamiya', 'tampermonkey',
                     'taobao', 'tapas', 'target', 'task', 'tasmota', 'tata', 'tauri', 'taxbuzz', 'tcs', 'teal',
                     'teamcity', 'teamspeak', 'teamviewer', 'ted', 'teepublic', 'teespring', 'tekton', 'tele5',
                     'telegram', 'telegraph', 'telequebec', 'temporal', 'tencentqq', 'tensorflow', 'teradata',
                     'teratail', 'termius', 'terraform', 'tesco', 'tesla', 'testcafe', 'testin', 'testinglibrary',
                     'testrail', 'tether', 'textpattern', 'tga', 'thangs', 'thealgorithms', 'theboringcompany',
                     'theconversation', 'thefinals', 'theirishtimes', 'themighty', 'themodelsresource',
                     'themoviedatabase', 'thenorthface', 'theodinproject', 'theregister', 'thesoundsresource',
                     'thespritersresource', 'thewashingtonpost', 'thingiverse', 'thinkpad', 'threadless', 'threads',
                     'threedotjs', 'threema', 'thumbtack', 'thunderbird', 'thunderstore', 'thurgauerkantonalbank',
                     'thymeleaf', 'ticketmaster', 'ticktick', 'tidal', 'tiddlywiki', 'tide', 'tidyverse', 'tietoevry',
                     'tiktok', 'tildapublishing', 'tile', 'timescale', 'tina', 'tinder', 'tindie', 'tinkercad',
                     'tinyletter', 'tistory', 'tmobile', 'tmux', 'todoist', 'toggl', 'toggltrack', 'tokyometro', 'toll',
                     'toml', 'tomorrowland', 'ton', 'topcoder', 'topdotgg', 'toptal', 'torbrowser', 'torproject',
                     'toshiba', 'totvs', 'tourbox', 'toyota', 'tplink', 'tqdm', 'tradingview', 'traefikmesh',
                     'traefikproxy', 'trailforks', 'trainerroad', 'trakt', 'transifex', 'transmission',
                     'transportforireland', 'transportforlondon', 'travisci', 'treehouse', 'trello', 'trendmicro',
                     'treyarch', 'tricentis', 'trilium', 'triller', 'trillertv', 'trino', 'tripadvisor', 'tripdotcom',
                     'trivy', 'trove', 'trpc', 'truenas', 'trueup', 'trulia', 'trustedshops', 'trustpilot', 'tryhackme',
                     'tryitonline', 'tsnode', 'tubi', 'tui', 'tumblr', 'tunein', 'turbo', 'turborepo', 'turbosquid',
                     'turkishairlines', 'turso', 'tutanota', 'tvtime', 'twilio', 'twinkly', 'twitch', 'twitter',
                     'typeform', 'typer', 'typescript', 'typo3', 'typst', 'uber', 'ubereats', 'ubiquiti', 'ubisoft',
                     'ublockorigin', 'ubuntu', 'ubuntumate', 'udacity', 'udemy', 'ufc', 'uikit', 'ulule', 'umami',
                     'umbraco', 'uml', 'unacademy', 'underarmour', 'underscoredotjs', 'undertale', 'unicode',
                     'unilever', 'uniqlo', 'uniqlo_ja', 'unitedairlines', 'unitednations', 'unity', 'unlicense',
                     'unocss', 'unraid', 'unrealengine', 'unsplash', 'untappd', 'upcloud', 'uphold', 'uplabs',
                     'upptime', 'ups', 'upstash', 'uptimekuma', 'uptobox', 'upwork', 'usps', 'utorrent', 'v', 'v2ex',
                     'v8', 'vaadin', 'vagrant', 'vala', 'valorant', 'valve', 'vapor', 'vault', 'vaultwarden',
                     'vauxhall', 'vbulletin', 'vectary', 'vectorlogozone', 'vectorworks', 'veeam', 'veepee', 'vega',
                     'vegas', 'velog', 'venmo', 'vercel', 'verdaccio', 'veritas', 'verizon', 'vespa', 'vexxhost',
                     'vfairs', 'viadeo', 'viaplay', 'viber', 'viblo', 'victoriametrics', 'victronenergy', 'vim',
                     'vimeo', 'vimeolivestream', 'virgin', 'virginatlantic', 'virginmedia', 'virtualbox', 'virustotal',
                     'visa', 'visualbasic', 'visualstudio', 'visualstudioappcenter', 'visualstudiocode', 'vite',
                     'vitess', 'vitest', 'vivaldi', 'vivawallet', 'vivino', 'vivint', 'vivo', 'vk', 'vlcmediaplayer',
                     'vmware', 'vodafone', 'voidlinux', 'voipdotms', 'volkswagen', 'volvo', 'vonage', 'vorondesign',
                     'vowpalwabbit', 'vox', 'vsco', 'vscodium', 'vtex', 'vuedotjs', 'vuetify', 'vulkan', 'vultr',
                     'vyond', 'w3schools', 'wacom', 'wagtail', 'wails', 'wakatime', 'walkman', 'wallabag',
                     'walletconnect', 'walmart', 'wantedly', 'wappalyzer', 'warnerbros', 'warp', 'wasabi', 'wasmcloud',
                     'wasmer', 'wattpad', 'wayland', 'waze', 'wazirx', 'wearos', 'weasyl', 'web3dotjs', 'webassembly',
                     'webauthn', 'webcomponentsdotorg', 'webdriverio', 'webex', 'webflow', 'webgl', 'weblate', 'webmin',
                     'webmoney', 'webpack', 'webrtc', 'webstorm', 'webtoon', 'webtrees', 'wechat', 'wegame',
                     'weightsandbiases', 'welcometothejungle', 'wellfound', 'wellsfargo', 'wemo', 'westerndigital',
                     'westernunion', 'wetransfer', 'wezterm', 'whatsapp', 'wheniwork', 'wii', 'wiiu', 'wikidata',
                     'wikidotgg', 'wikidotjs', 'wikimediacommons', 'wikimediafoundation', 'wikipedia', 'wikiquote',
                     'wikivoyage', 'winamp', 'windows', 'windows10', 'windows11', 'windows95', 'windowsterminal',
                     'windowsxp', 'wipro', 'wire', 'wireguard', 'wireshark', 'wise', 'wish', 'wistia', 'wix', 'wizzair',
                     'wolfram', 'wolframlanguage', 'wolframmathematica', 'wondershare', 'wondersharefilmora', 'woo',
                     'woocommerce', 'wordpress', 'workplace', 'worldhealthorganization', 'wpengine', 'wpexplorer',
                     'wprocket', 'writedotas', 'wwe', 'wwise', 'wyze', 'x', 'xamarin', 'xaml', 'xampp', 'xbox', 'xcode',
                     'xdadevelopers', 'xdotorg', 'xendit', 'xero', 'xfce', 'xiaomi', 'xing', 'xmpp', 'xo', 'xrp',
                     'xsplit', 'xstate', 'yale', 'yamahacorporation', 'yamahamotorcorporation', 'yaml', 'yammer',
                     'yandexcloud', 'yarn', 'ycombinator', 'yelp', 'yeti', 'yoast', 'youtube', 'youtubegaming',
                     'youtubekids', 'youtubemusic', 'youtubeshorts', 'youtubestudio', 'youtubetv', 'yr', 'yubico',
                     'zabka', 'zaim', 'zalando', 'zalo', 'zap', 'zapier', 'zara', 'zazzle', 'zcash', 'zcool', 'zdf',
                     'zebpay', 'zebratechnologies', 'zedindustries', 'zelle', 'zend', 'zendesk', 'zenn', 'zenodo',
                     'zensar', 'zerodha', 'zerply', 'zettlr', 'zhihu', 'zig', 'zigbee', 'ziggo', 'zilch', 'zillow',
                     'zincsearch', 'zingat', 'zod', 'zoho', 'zoiper', 'zomato', 'zoom', 'zorin', 'zotero', 'zsh',
                     'zulip', 'zyte']
